package net.sf.jbg.mojo;

import org.apache.maven.plugin.AbstractMojo;
import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.plugin.MojoFailureException;
import org.apache.maven.project.MavenProject;

/**
 * Finalizes the XSLT generator at the end of the build. Calls finalize on xslt
 * generator maven plugin.
 * <p>
 * By default runs in process-resources phase, if needed, customize the phase as
 * required. Generally should be run as the last execution of the generator in
 * the build (eg. if generate-test-resources phase is the last one you use the
 * generator in, finalize it in this phase).
 * 
 * @goal finalize
 * @phase process-resources
 */
public class FinalizeMojo extends AbstractMojo {

	/**
	 * The Maven project model.
	 * 
	 * @parameter expression="${project}"
	 * @required
	 * @readonly
	 */
	private MavenProject project;

	public void execute() throws MojoExecutionException, MojoFailureException {
		net.sf.xsltmp.FinalizeMojo mojo;
		mojo = new net.sf.xsltmp.FinalizeMojo();
		mojo.setProject(this.project);
		mojo.setLog(getLog());
		mojo.execute();
	}

}
