package net.sf.jbg.mojo;

import net.sf.xsltmp.FromManyBase;

import org.apache.maven.plugin.AbstractMojo;
import org.apache.maven.project.MavenProject;
import org.codehaus.plexus.archiver.manager.ArchiverManager;
import org.codehaus.plexus.util.StringUtils;

public abstract class JbgMojoBase extends AbstractMojo {

	/**
	 * The Maven project model.
	 * 
	 * @parameter expression="${project}"
	 * @required
	 * @readonly
	 */
	protected MavenProject project;

	/**
	 * To look up Archiver/UnArchiver implementations
	 * 
	 * @component
	 */
	protected ArchiverManager archiverManager;

	/**
	 * Which files from the source directory tree should be included in the
	 * transformation.
	 * <p>
	 * Specifies a fileset of source files in the comma- or space-separated list
	 * of patterns of files.
	 * 
	 * @parameter default-value="**\/*-beans.xml"
	 * @required
	 */
	protected String srcIncludes;

	/**
	 * Which files from the source directory tree should be excluded in the
	 * transformation.
	 * <p>
	 * Specifies a fileset of source files in the comma- or space-separated list
	 * of patterns of files.
	 * 
	 * @parameter
	 */
	protected String srcExcludes;

	/**
	 * Read the source files (XSL templates and XML transformation sources)
	 * using this encoding.
	 * 
	 * @parameter expression="${project.build.sourceEncoding}"
	 */
	private String sourceEncoding;

	public String getSourceEncoding() {
		if (StringUtils.isEmpty(sourceEncoding)) {
			sourceEncoding = System.getProperty("file.encoding");
			getLog().warn(
					"Source encoding has not been set, "
							+ "using platform encoding " + sourceEncoding
							+ ", i.e. build is platform dependent!");
		}
		return sourceEncoding;
	}

	protected void initMojo(FromManyBase mojo) {
		mojo.setProject(project);
		mojo.setArchiverManager(archiverManager);
		mojo.setLog(getLog());
		mojo.setSourceEncoding(getSourceEncoding());
		mojo.setSrcIncludes(srcIncludes);
		mojo.setSrcExcludes(srcExcludes);
	}

	public void setProject(MavenProject project) {
		this.project = project;
	}

	public void setArchiverManager(ArchiverManager archiverManager) {
		this.archiverManager = archiverManager;
	}

	public void setSrcIncludes(String srcIncludes) {
		this.srcIncludes = srcIncludes;
	}

	public void setSrcExcludes(String srcExcludes) {
		this.srcExcludes = srcExcludes;
	}

	public void setSourceEncoding(String sourceEncoding) {
		this.sourceEncoding = sourceEncoding;
	}

}
